summaryrefslogtreecommitdiffstats
path: root/konsolekalendar/main.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'konsolekalendar/main.cpp')
-rw-r--r--konsolekalendar/main.cpp16
1 files changed, 8 insertions, 8 deletions
diff --git a/konsolekalendar/main.cpp b/konsolekalendar/main.cpp
index 42f5dd992..14b892052 100644
--- a/konsolekalendar/main.cpp
+++ b/konsolekalendar/main.cpp
@@ -20,8 +20,8 @@
* Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA. *
* *
* As a special exception, permission is given to link this program *
* with any edition of Qt, and distribute the resulting executable, *
* without including the source code for Qt in the source distribution. *
* *
******************************************************************************/
/**
@@ -472,7 +472,7 @@ int main( int argc, char *argv[] )
<< "(" << option << ")"
<< endl;
- startdate = TQDate::fromString( option, Qt::ISODate );
+ startdate = TQDate::fromString( option, TQt::ISODate );
if ( !startdate.isValid() ) {
cout << i18n( "Invalid Start Date Specified: %1" ).
arg( option ).local8Bit()
@@ -497,7 +497,7 @@ int main( int argc, char *argv[] )
<< endl;
if ( option.upper() != "FLOAT" ) {
- starttime = TQTime::fromString( option, Qt::ISODate );
+ starttime = TQTime::fromString( option, TQt::ISODate );
if ( !starttime.isValid() ) {
cout << i18n( "Invalid Start Time Specified: %1" ).
arg( option ).local8Bit()
@@ -527,7 +527,7 @@ int main( int argc, char *argv[] )
<< "(" << option << ")"
<< endl;
- enddate = TQDate::fromString( option, Qt::ISODate );
+ enddate = TQDate::fromString( option, TQt::ISODate );
if ( !enddate.isValid() ) {
cout << i18n( "Invalid End Date Specified: %1" ).
arg( option ).local8Bit()
@@ -579,7 +579,7 @@ int main( int argc, char *argv[] )
<< endl;
if ( option.upper() != "FLOAT" ) {
- endtime = TQTime::fromString( option, Qt::ISODate );
+ endtime = TQTime::fromString( option, TQt::ISODate );
if ( !endtime.isValid() ) {
cout << i18n( "Invalid End Time Specified: %1" ).
arg( option ).local8Bit()
@@ -854,10 +854,10 @@ int main( int argc, char *argv[] )
// Some more debug prints
kdDebug() << "main | datetimestamp | StartDate="
- << startdatetime.toString( Qt::TextDate )
+ << startdatetime.toString( TQt::TextDate )
<< endl;
kdDebug() << "main | datetimestamp | EndDate="
- << enddatetime.toString( Qt::TextDate )
+ << enddatetime.toString( TQt::TextDate )
<< endl;
/***************************************************************************
@@ -20,8 +20,8 @@
* *
* As a special exception, permission is given to link this program *
- * with any edition of Qt, and distribute the resulting executable, *
- * without including the source code for Qt in the source distribution. *
+ * with any edition of TQt, and distribute the resulting executable, *
+ * without including the source code for TQt in the source distribution. *
* *
******************************************************************************/